import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.JPanel;

import percolation.Cell;
import percolation.Grid;

@SuppressWarnings("serial")
public class DisplayPanel extends JPanel {
  public static final int MAXSIZE = 500;
  private final int cellSize;
  private Grid grid;

  public DisplayPanel(Grid grid) {
    this.grid = grid;
    this.cellSize = MAXSIZE / grid.size();
    if (this.cellSize < 1)
      throw new IllegalArgumentException("displayed size can't exceed "
          + MAXSIZE);
    this.setPreferredSize(new Dimension(MAXSIZE, MAXSIZE));
    this.setBackground(Color.WHITE);
    this.setOpaque(true);
  }

  public void paintComponent(Graphics g) {
    super.paintComponent(g);
    for (int i = 0, x = 0; i < this.grid.size(); ++i, x += this.cellSize)
      for (int j = 0, y = 0; j < this.grid.size(); ++j, y += this.cellSize) {
        Cell c = this.grid.getCell(i, j);
        switch (c.getState()) {
        case BLOCKED:
          g.setColor(Color.BLACK);
          break;
        case OPEN:
          g.setColor(Color.WHITE);
          break;
        case INPUT:
          g.setColor(Color.YELLOW);
          break;
        case OUTPUT:
          g.setColor(Color.RED);
          break;
        case PERCOLATING:
          g.setColor(Color.ORANGE);
          break;
        }
        g.fillRect(x, y, this.cellSize, this.cellSize);
      }
  }
}
